@@ -228,7 +228,7 @@ repo_info = \
             "ret":["bool", True, None, None, False, True]
         },
         "create_config_maps":{
-            "args":["cluster_name", "config_map_user_settings"]
+            "args":[["cluster_name", False, "Name"], "config_map_user_settings"]
         },
         "create_namespace":{
             "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]]
